@@ -57,13 +57,16 @@ const char *Browser::SupportedExtensions[] =
 
 void Browser::Init()
 {
-	w = new Menu<MPD::Item>(0, MainStartY, COLS, MainHeight, Config.columns_in_browser ? Display::Columns() : "", Config.main_color, brNone);
+	static Display::ScreenFormat sf = { this, &Config.song_list_format };
+	
+	w = new Menu<MPD::Item>(0, MainStartY, COLS, MainHeight, Config.columns_in_browser && Config.titles_visibility ? Display::Columns() : "", Config.main_color, brNone);
 	w->HighlightColor(Config.main_highlight_color);
 	w->CyclicScrolling(Config.use_cyclic_scrolling);
 	w->CenteredCursor(Config.centered_cursor);
 	w->SetSelectPrefix(&Config.selected_item_prefix);
 	w->SetSelectSuffix(&Config.selected_item_suffix);
 	w->SetItemDisplayer(Display::Items);
+	w->SetItemDisplayerUserData(&sf);
 	w->SetGetStringFunction(ItemToString);
 	isInitialized = 1;
 }
@@ -520,6 +523,27 @@ void Browser::ChangeBrowseMode()
 	GetDirectory(itsBrowsedDir);
 	RedrawHeader = 1;
 }
+
+bool Browser::DeleteItem(const MPD::Item &item)
+{
+	// parent dir
+	if (item.type == itDirectory && item.song)
+		return false;
+	
+	// playlist creatd by mpd
+	if (!isLocal() && item.type == itPlaylist && CurrentDir() == "/")
+		return Mpd.DeletePlaylist(locale_to_utf_cpy(item.name));
+	
+	std::string path;
+	if (!isLocal())
+		path = Config.mpd_music_dir;
+	path += item.type == itSong ? item.song->GetFile() : item.name;
+	
+	if (item.type == itDirectory)
+		ClearDirectory(path);
+	
+	return remove(path.c_str()) == 0;
+}
 #endif // !WIN32
 
 void Browser::UpdateItemList()
@@ -552,7 +576,7 @@ std::string Browser::ItemToString(const MPD::Item &item, void *)
 		{
 			if (item.song)
 				return "[..]";
-			return "[" + ExtractTopDirectory(item.name) + "]";
+			return "[" + ExtractTopName(item.name) + "]";
 		}
 		case MPD::itSong:
 		{
@@ -563,7 +587,7 @@ std::string Browser::ItemToString(const MPD::Item &item, void *)
 		}
 		case MPD::itPlaylist:
 		{
-			return Config.browser_playlist_prefix.Str() + item.name;
+			return Config.browser_playlist_prefix.Str() + ExtractTopName(item.name);
 		}
 		default:
 		{
