@@ -18,10 +18,56 @@
  *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
  ***************************************************************************/
 
+#include <cassert>
+
 #include "display.h"
 #include "helpers.h"
-#include "info.h"
+#include "song_info.h"
 #include "playlist.h"
+#include "global.h"
+
+using Global::myScreen;
+
+namespace
+{
+	const my_char_t *toColumnName(char c)
+	{
+		switch (c)
+		{
+			case 'l':
+				return U("Time");
+			case 'f':
+				return U("Filename");
+			case 'D':
+				return U("Directory");
+			case 'a':
+				return U("Artist");
+			case 'A':
+				return U("Album Artist");
+			case 't':
+				return U("Title");
+			case 'b':
+				return U("Album");
+			case 'y':
+				return U("Year");
+			case 'n':
+			case 'N':
+				return U("Track");
+			case 'g':
+				return U("Genre");
+			case 'c':
+				return U("Composer");
+			case 'p':
+				return U("Performer");
+			case 'd':
+				return U("Disc");
+			case 'C':
+				return U("Comment");
+			default:
+				return U("?");
+		}
+	}
+}
 
 std::string Display::Columns()
 {
@@ -42,7 +88,7 @@ std::string Display::Columns()
 		if (it == Config.columns.end()-1)
 			width = COLS-where;
 		else if (last_fixed && it == next2last)
-			width = COLS-where-(++next2last)->width;
+			width = COLS-where-1-(++next2last)->width;
 		else
 			width = it->width*(it->fixed ? 1 : COLS/100.0);
 		
@@ -51,55 +97,7 @@ std::string Display::Columns()
 		{
 			for (size_t j = 0; j < it->type.length(); ++j)
 			{
-				switch (it->type[j])
-				{
-					case 'l':
-						tag += U("Time");
-						break;
-					case 'f':
-						tag += U("Filename");
-						break;
-					case 'D':
-						tag += U("Directory");
-						break;
-					case 'a':
-						tag += U("Artist");
-						break;
-					case 'A':
-						tag += U("Album Artist");
-						break;
-					case 't':
-						tag += U("Title");
-						break;
-					case 'b':
-						tag += U("Album");
-						break;
-					case 'y':
-						tag += U("Year");
-						break;
-					case 'n':
-					case 'N':
-						tag += U("Track");
-						break;
-					case 'g':
-						tag += U("Genre");
-						break;
-					case 'c':
-						tag += U("Composer");
-						break;
-					case 'p':
-						tag += U("Performer");
-						break;
-					case 'd':
-						tag += U("Disc");
-						break;
-					case 'C':
-						tag += U("Comment");
-						break;
-					default:
-						tag += U("?");
-						break;
-				}
+				tag += toColumnName(it->type[j]);
 				tag += '/';
 			}
 			tag.resize(tag.length()-1);
@@ -127,11 +125,14 @@ std::string Display::Columns()
 	return TO_STRING(result);
 }
 
-void Display::SongsInColumns(const MPD::Song &s, void *, Menu<MPD::Song> *menu)
+void Display::SongsInColumns(const MPD::Song &s, void *data, Menu<MPD::Song> *menu)
 {
 	if (!s.Localized())
 		const_cast<MPD::Song *>(&s)->Localize();
 	
+	/// FIXME: This function is pure mess, it needs to be
+	/// rewritten and unified with Display::Columns() a bit.
+	
 	bool is_now_playing = menu == myPlaylist->Items && (menu->isFiltered() ? s.GetPosition() : menu->CurrentlyDrawedPosition()) == size_t(myPlaylist->NowPlaying);
 	if (is_now_playing)
 		*menu << Config.now_playing_prefix;
@@ -139,9 +140,14 @@ void Display::SongsInColumns(const MPD::Song &s, void *, Menu<MPD::Song> *menu)
 	if (Config.columns.empty())
 		return;
 	
-	bool separate_albums = Config.playlist_separate_albums
-			&& s.GetPosition()+1 < myPlaylist->Items->Size()
-			&& (*myPlaylist->Items)[s.GetPosition()+1].GetAlbum() != s.GetAlbum();
+	assert(data);
+	bool separate_albums = false;
+	if (Config.playlist_separate_albums && menu->CurrentlyDrawedPosition()+1 < menu->Size())
+	{
+		MPD::Song *next = static_cast<ScreenFormat *>(data)->screen->GetSong(menu->CurrentlyDrawedPosition()+1);
+		if (next && next->GetAlbum() != s.GetAlbum())
+			separate_albums = true;
+	}
 	if (separate_albums)
 		*menu << fmtUnderline;
 	
@@ -169,7 +175,7 @@ void Display::SongsInColumns(const MPD::Song &s, void *, Menu<MPD::Song> *menu)
 		if (it == Config.columns.end()-1)
 			width = menu->GetWidth()-where;
 		else if (last_fixed && it == next2last)
-			width = COLS-where-(++next2last)->width;
+			width = COLS-where-1-(++next2last)->width;
 		else
 			width = it->width*(it->fixed ? 1 : COLS/100.0);
 		
@@ -178,56 +184,7 @@ void Display::SongsInColumns(const MPD::Song &s, void *, Menu<MPD::Song> *menu)
 		std::string tag;
 		for (size_t i = 0; i < it->type.length(); ++i)
 		{
-			switch (it->type[i])
-			{
-				case 'l':
-					get = &MPD::Song::GetLength;
-					break;
-				case 'D':
-					get = &MPD::Song::GetDirectory;
-					break;
-				case 'f':
-					get = &MPD::Song::GetName;
-					break;
-				case 'a':
-					get = &MPD::Song::GetArtist;
-					break;
-				case 'A':
-					get = &MPD::Song::GetAlbumArtist;
-					break;
-				case 'b':
-					get = &MPD::Song::GetAlbum;
-					break;
-				case 'y':
-					get = &MPD::Song::GetDate;
-					break;
-				case 'n':
-					get = &MPD::Song::GetTrackNumber;
-					break;
-				case 'N':
-					get = &MPD::Song::GetTrack;
-					break;
-				case 'g':
-					get = &MPD::Song::GetGenre;
-					break;
-				case 'c':
-					get = &MPD::Song::GetComposer;
-					break;
-				case 'p':
-					get = &MPD::Song::GetPerformer;
-					break;
-				case 'd':
-					get = &MPD::Song::GetDisc;
-					break;
-				case 'C':
-					get = &MPD::Song::GetComment;
-					break;
-				case 't':
-					get = &MPD::Song::GetTitle;
-					break;
-				default:
-					break;
-			}
+			get = toGetFunction(it->type[i]);
 			tag = get ? s.GetTags(get) : "";
 			if (!tag.empty())
 				break;
@@ -296,9 +253,14 @@ void Display::Songs(const MPD::Song &s, void *data, Menu<MPD::Song> *menu)
 	if (is_now_playing)
 		*menu << Config.now_playing_prefix;
 	
-	bool separate_albums = Config.playlist_separate_albums
-			&& s.GetPosition()+1 < myPlaylist->Items->Size()
-			&& (*myPlaylist->Items)[s.GetPosition()+1].GetAlbum() != s.GetAlbum();
+	assert(data);
+	bool separate_albums = false;
+	if (Config.playlist_separate_albums && menu->CurrentlyDrawedPosition()+1 < menu->Size())
+	{
+		MPD::Song *next = static_cast<ScreenFormat *>(data)->screen->GetSong(menu->CurrentlyDrawedPosition()+1);
+		if (next && next->GetAlbum() != s.GetAlbum())
+			separate_albums = true;
+	}
 	if (separate_albums)
 	{
 		*menu << fmtUnderline;
@@ -307,7 +269,7 @@ void Display::Songs(const MPD::Song &s, void *data, Menu<MPD::Song> *menu)
 	
 	bool discard_colors = Config.discard_colors_if_item_is_selected && menu->isSelected(menu->CurrentlyDrawedPosition());
 	
-	std::string line = s.toString(*static_cast<std::string *>(data), "$");
+	std::string line = s.toString(*static_cast<ScreenFormat *>(data)->format, "$");
 	for (std::string::const_iterator it = line.begin(); it != line.end(); ++it)
 	{
 		if (*it == '$')
@@ -360,7 +322,7 @@ void Display::Tags(const MPD::Song &s, void *data, Menu<MPD::Song> *menu)
 	size_t i = static_cast<Menu<std::string> *>(data)->Choice();
 	if (i < 11)
 	{
-		ShowTag(*menu, s.GetTags(Info::Tags[i].Get));
+		ShowTag(*menu, s.GetTags(SongInfo::Tags[i].Get));
 	}
 	else if (i == 12)
 	{
@@ -371,7 +333,7 @@ void Display::Tags(const MPD::Song &s, void *data, Menu<MPD::Song> *menu)
 	}
 }
 
-void Display::Items(const MPD::Item &item, void *, Menu<MPD::Item> *menu)
+void Display::Items(const MPD::Item &item, void *data, Menu<MPD::Item> *menu)
 {
 	switch (item.type)
 	{
@@ -382,31 +344,31 @@ void Display::Items(const MPD::Item &item, void *, Menu<MPD::Item> *menu)
 				*menu << "[..]";
 				return;
 			}
-			*menu << "[" << ExtractTopDirectory(item.name) << "]";
+			*menu << "[" << ExtractTopName(item.name) << "]";
 			return;
 		}
 		case MPD::itSong:
 			if (!Config.columns_in_browser)
-				Display::Songs(*item.song, &Config.song_list_format, reinterpret_cast<Menu<MPD::Song> *>(menu));
+				Display::Songs(*item.song, data, reinterpret_cast<Menu<MPD::Song> *>(menu));
 			else
-				Display::SongsInColumns(*item.song, 0, reinterpret_cast<Menu<MPD::Song> *>(menu));
+				Display::SongsInColumns(*item.song, data, reinterpret_cast<Menu<MPD::Song> *>(menu));
 			return;
 		case MPD::itPlaylist:
-			*menu << Config.browser_playlist_prefix << item.name;
+			*menu << Config.browser_playlist_prefix << ExtractTopName(item.name);
 			return;
 		default:
 			return;
 	}
 }
 
-void Display::SearchEngine(const std::pair<Buffer *, MPD::Song *> &pair, void *, Menu< std::pair<Buffer *, MPD::Song *> > *menu)
+void Display::SearchEngine(const std::pair<Buffer *, MPD::Song *> &pair, void *data, Menu< std::pair<Buffer *, MPD::Song *> > *menu)
 {
 	if (pair.second)
 	{
 		if (!Config.columns_in_search_engine)
-			Display::Songs(*pair.second, &Config.song_list_format, reinterpret_cast<Menu<MPD::Song> *>(menu));
+			Display::Songs(*pair.second, data, reinterpret_cast<Menu<MPD::Song> *>(menu));
 		else
-			Display::SongsInColumns(*pair.second, 0, reinterpret_cast<Menu<MPD::Song> *>(menu));
+			Display::SongsInColumns(*pair.second, data, reinterpret_cast<Menu<MPD::Song> *>(menu));
 	}
 	
 	else
