@@ -43,7 +43,7 @@ bool ConnectToMPD()
 void ParseArgv(int argc, char **argv)
 {
 	bool quit = 0;
-	std::string now_playing_format = "{{(%l) }{{%a - }%t}}|{%f}}";
+	std::string now_playing_format = "{{{(%l) }{{%a - }%t}}|{%f}}";
 	
 	for (int i = 1; i < argc; ++i)
 	{
@@ -105,9 +105,6 @@ void ParseArgv(int argc, char **argv)
 #			ifdef HAVE_TAGLIB_H
 			<< " taglib"
 #			endif
-#			ifdef HAVE_PTHREAD_H
-			<< " threads"
-#			endif
 #			ifdef _UTF8
 			<< " unicode"
 #			endif
@@ -150,13 +147,15 @@ void ParseArgv(int argc, char **argv)
 			{
 				if (argc > ++i)
 				{
-					// apply additional pair of braces
-					now_playing_format = "{";
-					now_playing_format += argv[i];
-					now_playing_format += "}";
-					Replace(now_playing_format, "\\n", "\n");
-					Replace(now_playing_format, "\\t", "\t");
-					MPD::Song::ValidateFormat("now-playing format", now_playing_format);
+					if (MPD::Song::isFormatOk("now-playing format", argv[i]))
+					{
+						// apply additional pair of braces
+						now_playing_format = "{";
+						now_playing_format += argv[i];
+						now_playing_format += "}";
+						Replace(now_playing_format, "\\n", "\n");
+						Replace(now_playing_format, "\\t", "\t");
+					}
 				}
 				std::cout << utf_to_locale_cpy(Mpd.GetCurrentSong().toString(now_playing_format)) << "\n";
 			}
@@ -250,7 +249,7 @@ bool CaseInsensitiveSorting::operator()(const MPD::Item &a, const MPD::Item &b)
 		switch (a.type)
 		{
 			case MPD::itDirectory:
-				return cmp(ExtractTopDirectory(a.name), ExtractTopDirectory(b.name)) < 0;
+				return cmp(ExtractTopName(a.name), ExtractTopName(b.name)) < 0;
 			case MPD::itPlaylist:
 				return cmp(a.name, b.name) < 0;
 			case MPD::itSong:
@@ -369,12 +368,18 @@ std::string GetLineValue(std::string &line, char a, char b, bool once)
 	return result;
 }
 
-std::string ExtractTopDirectory(const std::string &s)
+std::string ExtractTopName(const std::string &s)
 {
 	size_t slash = s.rfind("/");
 	return slash != std::string::npos ? s.substr(++slash) : s;
 }
 
+std::string PathGoDownOneLevel(const std::string &path)
+{
+	size_t i = path.rfind('/');
+	return i == std::string::npos ? "/" : path.substr(0, i);
+}
+
 std::basic_string<my_char_t> Scroller(const std::basic_string<my_char_t> &str, size_t &pos, size_t width)
 {
 	std::basic_string<my_char_t> s(str);
@@ -408,12 +413,3 @@ std::basic_string<my_char_t> Scroller(const std::basic_string<my_char_t> &str, s
 	return result;
 }
 
-#ifdef HAVE_CURL_CURL_H
-size_t write_data(char *buffer, size_t size, size_t nmemb, void *data)
-{
-	size_t result = size*nmemb;
-	static_cast<std::string *>(data)->append(buffer, result);
-	return result;
-}
-#endif // HAVE_CURL_CURL_H
-
