@@ -97,6 +97,16 @@ namespace
 	bool order_resize = 0;
 	size_t header_height, footer_start_y, footer_height;
 	
+	void check_screen_min_size()
+	{
+		if (COLS < 20 || MainHeight < 3)
+		{
+			DestroyScreen();
+			std::cout << "Screen is too small!\n";
+			exit(1);
+		}
+	}
+	
 	void resize_screen()
 	{
 		order_resize = 0;
@@ -122,12 +132,7 @@ namespace
 		RedrawHeader = 1;
 		MainHeight = LINES-(Config.new_design ? 7 : 4);
 		
-		if (COLS < 20 || MainHeight < 3)
-		{
-			DestroyScreen();
-			std::cout << "Screen is too small!\n";
-			exit(1);
-		}
+		check_screen_min_size();
 		
 		if (!Config.header_visibility)
 			MainHeight += 2;
@@ -272,6 +277,7 @@ int main(int argc, char *argv[])
 		Config.statusbar_visibility = 0;
 	
 	SetWindowsDimensions(header_height, footer_start_y, footer_height);
+	check_screen_min_size();
 	
 	wHeader = new Window(0, 0, COLS, header_height, "", Config.header_color, brNone);
 	if (Config.header_visibility || Config.new_design)
@@ -928,6 +934,9 @@ int main(int argc, char *argv[])
 			else if (myScreen == myPlaylist && !myPlaylist->Items->Empty())
 			{
 				CHECK_PLAYLIST_FOR_FILTERING;
+				// remove search results as we may move them to different positions, but
+				// search rememebers positions and may point to wrong ones after that.
+				myPlaylist->Items->Search("");
 				wFooter->SetTimeout(50);
 				if (myPlaylist->Items->hasSelected())
 				{
@@ -1006,6 +1015,9 @@ int main(int argc, char *argv[])
 			}
 			else if (myScreen->ActiveWindow() == myPlaylistEditor->Content && !myPlaylistEditor->Content->Empty())
 			{
+				// remove search results as we may move them to different positions, but
+				// search rememebers positions and may point to wrong ones after that.
+				myPlaylistEditor->Content->Search("");
 				wFooter->SetTimeout(50);
 				if (myPlaylistEditor->Content->hasSelected())
 				{
@@ -1060,6 +1072,9 @@ int main(int argc, char *argv[])
 			else if (myScreen == myPlaylist && !myPlaylist->Items->Empty())
 			{
 				CHECK_PLAYLIST_FOR_FILTERING;
+				// remove search results as we may move them to different positions, but
+				// search rememebers positions and may point to wrong ones after that.
+				myPlaylist->Items->Search("");
 				wFooter->SetTimeout(50);
 				if (myPlaylist->Items->hasSelected())
 				{
@@ -1133,6 +1148,9 @@ int main(int argc, char *argv[])
 			}
 			else if (myScreen->ActiveWindow() == myPlaylistEditor->Content && !myPlaylistEditor->Content->Empty())
 			{
+				// remove search results as we may move them to different positions, but
+				// search rememebers positions and may point to wrong ones after that.
+				myPlaylistEditor->Content->Search("");
 				wFooter->SetTimeout(50);
 				if (myPlaylistEditor->Content->hasSelected())
 				{
@@ -1189,6 +1207,9 @@ int main(int argc, char *argv[])
 				ShowMessage("No selected items to move!");
 				continue;
 			}
+			// remove search results as we may move them to different positions, but
+			// search rememebers positions and may point to wrong ones after that.
+			myPlaylist->Items->Search("");
 			Playlist::BlockUpdate = 1;
 			size_t pos = myPlaylist->Items->Choice();
 			std::vector<size_t> list;
@@ -1248,7 +1269,8 @@ int main(int argc, char *argv[])
 				else
 				{
 					static const char lastfm_url[] = "lastfm://";
-					if (path.compare(0, static_strlen(lastfm_url), lastfm_url) == 0)
+					if (path.compare(0, static_strlen(lastfm_url), lastfm_url) == 0
+					||  path.find(".pls", path.length()-4) != std::string::npos)
 						Mpd.LoadPlaylist(path);
 					else
 						Mpd.Add(path);
