@@ -25,14 +25,6 @@
 #include "menu.h"
 #include "scrollpad.h"
 
-#ifdef HAVE_PTHREAD_H
-# include <pthread.h>
-#else
-# define pthread_mutex_lock(x);
-# define pthread_mutex_unlock(x);
-# define pthread_exit(x) return (x)
-#endif // HAVE_PTHREAD_H
-
 using namespace NCurses;
 
 typedef std::pair<std::string, std::string> string_pair;
