@@ -45,20 +45,22 @@ void PlaylistEditor::Init()
 	RightColumnStartX = LeftColumnWidth+1;
 	RightColumnWidth = COLS-LeftColumnWidth-1;
 	
-	Playlists = new Menu<std::string>(0, MainStartY, LeftColumnWidth, MainHeight, "Playlists", Config.main_color, brNone);
+	Playlists = new Menu<std::string>(0, MainStartY, LeftColumnWidth, MainHeight, Config.titles_visibility ? "Playlists" : "", Config.main_color, brNone);
 	Playlists->HighlightColor(Config.active_column_color);
 	Playlists->CyclicScrolling(Config.use_cyclic_scrolling);
 	Playlists->CenteredCursor(Config.centered_cursor);
 	Playlists->SetItemDisplayer(Display::Generic);
 	
-	Content = new Menu<MPD::Song>(RightColumnStartX, MainStartY, RightColumnWidth, MainHeight, "Playlist's content", Config.main_color, brNone);
+	static Display::ScreenFormat sf = { this, &Config.song_list_format };
+	
+	Content = new Menu<MPD::Song>(RightColumnStartX, MainStartY, RightColumnWidth, MainHeight, Config.titles_visibility ? "Playlist's content" : "", Config.main_color, brNone);
 	Content->HighlightColor(Config.main_highlight_color);
 	Content->CyclicScrolling(Config.use_cyclic_scrolling);
 	Content->CenteredCursor(Config.centered_cursor);
 	Content->SetSelectPrefix(&Config.selected_item_prefix);
 	Content->SetSelectSuffix(&Config.selected_item_suffix);
 	Content->SetItemDisplayer(Display::Songs);
-	Content->SetItemDisplayerUserData(&Config.song_list_format);
+	Content->SetItemDisplayerUserData(&sf);
 	Content->SetGetStringFunction(Playlist::SongToString);
 	Content->SetGetStringFunctionUserData(&Config.song_list_format);
 	
@@ -116,7 +118,7 @@ void PlaylistEditor::SwitchTo()
 
 void PlaylistEditor::Update()
 {
-	if (Playlists->Empty())
+	if (Playlists->ReallyEmpty())
 	{
 		Content->Clear();
 		MPD::TagList list;
@@ -131,15 +133,15 @@ void PlaylistEditor::Update()
 		Playlists->Refresh();
 	}
 	
-	if (!Playlists->Empty() && Content->Empty())
+	if (!Playlists->Empty() && Content->ReallyEmpty())
 	{
 		Content->Reset();
 		MPD::SongList list;
 		Mpd.GetPlaylistContent(locale_to_utf_cpy(Playlists->Current()), list);
 		if (!list.empty())
-			Content->SetTitle("Playlist's content (" + IntoStr(list.size()) + " item" + (list.size() == 1 ? ")" : "s)"));
+			Content->SetTitle(Config.titles_visibility ? "Playlist's content (" + IntoStr(list.size()) + " item" + (list.size() == 1 ? ")" : "s)") : "");
 		else
-			Content->SetTitle("Playlist's content");
+			Content->SetTitle(Config.titles_visibility ? "Playlist's content" : "");
 		bool bold = 0;
 		for (MPD::SongList::const_iterator it = list.begin(); it != list.end(); ++it)
 		{
@@ -159,14 +161,14 @@ void PlaylistEditor::Update()
 		Content->Display();
 	}
 	
-	if (w == Content && Content->Empty())
+	if (w == Content && Content->ReallyEmpty())
 	{
 		Content->HighlightColor(Config.main_highlight_color);
 		Playlists->HighlightColor(Config.active_column_color);
 		w = Playlists;
 	}
 	
-	if (Content->Empty())
+	if (Content->ReallyEmpty())
 	{
 		*Content << XY(0, 0) << "Playlist is empty.";
 		Content->Window::Refresh();
