@@ -61,11 +61,14 @@ size_t SearchEngine::SearchButton = 14;
 
 void SearchEngine::Init()
 {
+	static Display::ScreenFormat sf = { this, &Config.song_list_format };
+	
 	w = new Menu< std::pair<Buffer *, MPD::Song *> >(0, MainStartY, COLS, MainHeight, "", Config.main_color, brNone);
 	w->HighlightColor(Config.main_highlight_color);
 	w->CyclicScrolling(Config.use_cyclic_scrolling);
 	w->CenteredCursor(Config.centered_cursor);
 	w->SetItemDisplayer(Display::SearchEngine);
+	w->SetItemDisplayerUserData(&sf);
 	w->SetSelectPrefix(&Config.selected_item_prefix);
 	w->SetSelectSuffix(&Config.selected_item_suffix);
 	w->SetGetStringFunction(SearchEngineOptionToString);
@@ -152,7 +155,7 @@ void SearchEngine::EnterPressed()
 		if (!w->Back().first)
 		{
 			if (Config.columns_in_search_engine)
-				w->SetTitle(Display::Columns());
+				w->SetTitle(Config.titles_visibility ? Display::Columns() : "");
 			size_t found = w->Size()-SearchEngine::StaticOptions;
 			found += 3; // don't count options inserted below
 			w->InsertSeparator(ResetButton+1);
@@ -337,6 +340,36 @@ void SearchEngine::Scroll(int input)
 	}
 }
 
+void SearchEngine::SelectAlbum()
+{
+	size_t pos = w->Choice();
+	if (pos < StaticOptions)
+		return;		// not on a song
+	
+	std::string album = w->at(pos).second->GetAlbum();
+
+	// select song under cursor
+	w->Select(pos, 1);
+
+	// go up
+	while (pos > StaticOptions)
+	{
+		if (w->at(--pos).second->GetAlbum() != album)
+			break;
+		else
+			w->Select(pos, 1);
+	}
+
+	// go down
+	while (pos < w->Size() - 1)
+	{
+		if (w->at(++pos).second->GetAlbum() != album)
+			break;
+		else
+			w->Select(pos, 1);
+	}
+}
+
 void SearchEngine::Prepare()
 {
 	for (size_t i = 0; i < w->Size(); ++i)
