@@ -333,7 +333,7 @@ void NcmpcppConfig::SetDefaults()
 {
 	mpd_host = "localhost";
 	empty_tag = "<empty>";
-	song_list_columns_format = "(7f)[green]{l} (25)[cyan]{a} (40)[]{t} (30)[red]{b}";
+	song_list_columns_format = "(7f)[green]{l} (25)[cyan]{a} (40)[]{t|f} (30)[red]{b}";
 	song_list_format = "{{%a - }{%t}|{$8%f$9}$R{$3(%l)$9}}";
 	song_status_format = "{{{%a{ \"%b\"{ (%y)}} - }{%t}}|{%f}}";
 	song_status_format_no_colors = song_status_format;
@@ -410,6 +410,7 @@ void NcmpcppConfig::SetDefaults()
 	browser_sort_by_mtime = false;
 	tag_editor_extended_numeration = false;
 	media_library_display_date = true;
+	media_library_display_empty_tag = true;
 	media_library_disable_two_column_mode = false;
 	discard_colors_if_item_is_selected = true;
 	store_lyrics_in_song_dir = false;
@@ -1047,6 +1048,10 @@ void NcmpcppConfig::Read()
 			{
 				media_library_display_date = v == "yes";
 			}
+			else if (cl.find("media_library_display_empty_tag") != std::string::npos)
+			{
+				media_library_display_empty_tag = v == "yes";
+			}
 			else if (cl.find("media_library_disable_two_column_mode") != std::string::npos)
 			{
 				media_library_disable_two_column_mode = v == "yes";
