@@ -49,10 +49,10 @@
 # define KEY_BACKSPACE 8
 #else
 // NOTICE: redefine BUTTON2_PRESSED as it doesn't always work, I noticed
-// that it sometimes returns 134217728 instead of expected mask, so the
+// that it sometimes returns 134217728 (2^27) instead of expected mask, so the
 // modified define does it right but is rather experimental.
 # undef BUTTON2_PRESSED
-# define BUTTON2_PRESSED (NCURSES_MOUSE_MASK(2, NCURSES_BUTTON_PRESSED) | 134217728U)
+# define BUTTON2_PRESSED (NCURSES_MOUSE_MASK(2, NCURSES_BUTTON_PRESSED) | (1U << 27))
 #endif // USE_PDCURSES
 
 #ifdef _UTF8
